# Autogenerated by Astropy-affiliated package astropy_helpers's setup.py on 2018-01-22 20:28:51
from __future__ import unicode_literals
import datetime

version = "3.0rc2"
githash = "071fd45b7ab2133ab0e6d6ca953cd114278210af"


major = 3
minor = 0
bugfix = 0

release = True
timestamp = datetime.datetime(2018, 1, 22, 20, 28, 51)
debug = False

try:
    from ._compiler import compiler
except ImportError:
    compiler = "unknown"

try:
    from .cython_version import cython_version
except ImportError:
    cython_version = "unknown"
